@@ -22,7 +22,7 @@ def create_theme(filepath):
                                      (filename + '.sample.png')))
 
 
-def set_theme(filename, cs_file, restore=False):
+def set_theme(filename, cs_file, vte, restore=False):
     if(path.join(config.WALL_DIR, filename)):
         if(not restore):
             color.execute_gcolorchange(cs_file)
@@ -33,7 +33,7 @@ def set_theme(filename, cs_file, restore=False):
         pywal.wallpaper.change(path.join(config.WALL_DIR, filename))
         image = pywal.image.get(path.join(config.WALL_DIR, cs_file))
         colors = pywal.colors.get(image, config.WALL_DIR)
-        pywal.sequences.send(colors, False, config.WALL_DIR)
+        pywal.sequences.send(colors, vte, config.WALL_DIR)
         pywal.export.color(colors, 'css',
                            path.join(config.WALL_DIR, 'current.css'))
         pywal.export.color(colors, 'shell',
@@ -73,18 +73,19 @@ def delete_theme(filename):
            (cache_file.replace('/', '_').replace('.', '_') + ".json")))
 
 
-def show_current():
+def get_current(show=False):
     image = realpath(path.join(config.WALL_DIR, '.current')).split('/').pop()
-    print(image)
+    if show:
+        print(image)
     return image
 
 
 def shuffle_colors(filename):
     try:
         colors = color.get_color_list(filename)
-        shuffled_colors = colors[1:8]
+        shuffled_colors = colors[1:7]
         shuffle(shuffled_colors)
-        colors = colors[:1] + shuffled_colors + colors[8:]
+        colors = colors[:1] + shuffled_colors + colors[7:]
         sample.create_sample(colors, f=path.join(config.SAMPLE_DIR,
                              filename + '.sample.png'))
         color.write_colors(filename, colors)
